==> haskell-lifted-async-0.10.2.7-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lifted-async
version:              0.10.2.7
visibility:           public
id:                   lifted-async-0.10.2.7-E7WORlsZgqC1EmmDUnSP6u
key:                  lifted-async-0.10.2.7-E7WORlsZgqC1EmmDUnSP6u
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2024 Mitsutoshi Aoe
maintainer:           Mitsutoshi Aoe <me@maoe.name>
author:               Mitsutoshi Aoe
homepage:             https://github.com/maoe/lifted-async
synopsis:
    Run lifted IO operations asynchronously and wait for their results

description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.

category:             Concurrency
abi:                  8990e26b8024a09c5c1ee3a6c38721aa
exposed:              True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lifted-async
hs-libraries:         HSlifted-async-0.10.2.7-E7WORlsZgqC1EmmDUnSP6u
depends:
    async-2.2.5-HIvtQdOwlf5Hsyin6u1n7Q base-4.17.2.1
    constraints-0.13.4-9t7M4RAom435nssV0Rpobx
    lifted-base-0.2.3.12-5aJT0Ukpe9IIhgidyvotpP
    monad-control-1.0.3.1-2ox58PDyrrF9r8TgoOtkMn
    transformers-base-0.4.6-4mAULAIhjKjG98g1VZHGsY

haddock-interfaces:
    /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock

haddock-html:         /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lifted-async-0.10.2.7-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lifted-async
version:              0.10.2.7
visibility:           public
id:                   lifted-async-0.10.2.7-Gl6ZQSYFCuk1D7YRlBTj9s
key:                  lifted-async-0.10.2.7-Gl6ZQSYFCuk1D7YRlBTj9s
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2024 Mitsutoshi Aoe
maintainer:           Mitsutoshi Aoe <me@maoe.name>
author:               Mitsutoshi Aoe
homepage:             https://github.com/maoe/lifted-async
synopsis:
    Run lifted IO operations asynchronously and wait for their results

description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.

category:             Concurrency
abi:                  d3ab20571eaf859a8ce6cdd11b22188e
exposed:              True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lifted-async-0.10.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lifted-async
hs-libraries:         HSlifted-async-0.10.2.7-Gl6ZQSYFCuk1D7YRlBTj9s
depends:
    async-2.2.5-HIvtQdOwlf5Hsyin6u1n7Q base-4.17.2.1
    constraints-0.13.4-9t7M4RAom435nssV0Rpobx
    lifted-base-0.2.3.12-5aJT0Ukpe9IIhgidyvotpP
    monad-control-1.0.3.1-2ox58PDyrrF9r8TgoOtkMn
    transformers-base-0.4.6-4mAULAIhjKjG98g1VZHGsY

haddock-interfaces:
    /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock

haddock-html:         /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
